@@ -4,11 +4,17 @@ from os import makedirs, path
 from shutil import rmtree
 from tempfile import mkdtemp
 
+try:
+    from os import fspath
+except ImportError:
+    fspath = str
+
 log = logging.getLogger(__name__)
 
 
 def create_dir(pth):
     """Equivalent of `mkdir -p`"""
+    pth = fspath(pth)
     if not path.isdir(pth):
         try:
             makedirs(pth)
@@ -19,7 +25,7 @@ def create_dir(pth):
 def hasext(fname, ext):
     if ext[0] != ".":
         ext = "." + ext
-    return path.splitext(fname)[1].lower() == ext.lower()
+    return path.splitext(fspath(fname))[1].lower() == ext.lower()
 
 
 @contextmanager
