@@ -2,15 +2,17 @@ from os import path
 
 from pytest import importorskip
 
+from miutil import fspath
+
 web = importorskip("miutil.web")
 
 
 def test_get_file(tmp_path):
-    tmpdir = str(tmp_path / "get_file")
-    assert not path.exists(tmpdir)
+    tmpdir = tmp_path / "get_file"
+    assert not path.exists(fspath(tmpdir))
     web.get_file(
         "README.rst",
         "https://github.com/AMYPAD/miutil/raw/master/README.rst",
         cache_dir=tmpdir,
     )
-    assert path.exists(path.join(tmpdir, "README.rst"))
+    assert path.exists(fspath(tmpdir / "README.rst"))
